@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2018-2022 Boran Adas and other RDKit contributors
+//  Copyright (C) 2018-2025 Boran Adas and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -30,6 +30,8 @@ struct RDKIT_FINGERPRINTS_EXPORT AdditionalOutput {
                std::vector<std::pair<std::uint32_t, std::uint32_t>>>;
   using bitPathsType = std::map<std::uint64_t, std::vector<std::vector<int>>>;
   using atomCountsType = std::vector<unsigned int>;
+  using atomsPerBitType =
+      std::map<std::uint64_t, std::vector<std::vector<int>>>;
 
   // numAtoms long
   atomToBitsType *atomToBits = nullptr;
@@ -46,6 +48,9 @@ struct RDKIT_FINGERPRINTS_EXPORT AdditionalOutput {
   // atom count for molecule.
   atomCountsType *atomCounts = nullptr;
 
+  // maps bitId -> vector of atoms involved in setting that bit
+  atomsPerBitType *atomsPerBit = nullptr;
+
   void allocateAtomToBits() {
     atomToBitsHolder.reset(new atomToBitsType);
     atomToBits = atomToBitsHolder.get();
@@ -62,12 +67,17 @@ struct RDKIT_FINGERPRINTS_EXPORT AdditionalOutput {
     atomCountsHolder.reset(new atomCountsType);
     atomCounts = atomCountsHolder.get();
   }
+  void allocateAtomsPerBit() {
+    atomsPerBitHolder.reset(new atomsPerBitType);
+    atomsPerBit = atomsPerBitHolder.get();
+  }
 
  private:
   std::unique_ptr<atomToBitsType> atomToBitsHolder;
   std::unique_ptr<bitInfoMapType> bitInfoMapHolder;
   std::unique_ptr<bitPathsType> bitPathsHolder;
   std::unique_ptr<atomCountsType> atomCountsHolder;
+  std::unique_ptr<atomsPerBitType> atomsPerBitHolder;
 };
 
 /*!
@@ -451,7 +461,12 @@ FingerprintGenerator<std::uint64_t>::getSparseCountFingerprint(
     const std::vector<std::uint32_t> *,
     const std::vector<std::uint32_t> *) const;
 
-enum class FPType { AtomPairFP, MorganFP, RDKitFP, TopologicalTorsionFP };
+enum class FPType {
+  AtomPairFP,
+  MorganFP,
+  RDKitFP,
+  TopologicalTorsionFP
+};
 
 //! used to indicate errors for unimplemented fp types in convenience
 //! functions
