@@ -194,6 +194,23 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSpace {
       const SubstructMatchParameters &matchParams = SubstructMatchParameters(),
       const SynthonSpaceSearchParams &params = SynthonSpaceSearchParams());
 
+  /*!
+   * Perform a substructure search with the given query molecule across
+   * the synthonspace library.  Duplicate SMILES strings produced by
+   * different reactions will be returned.  Search results are returned
+   * incrementally through the provided callback, which will receive
+   * at most `toTryChunkSize` sized lists of ROMols at a time, thereby
+   * reducing the amount of memory required to hold search results.
+   *
+   * @param query : query molecule
+   * @param callback: user-provided callback receiving chunks of ROMols.
+   * @param params : (optional) settings for the search
+   */
+  void substructureSearch(
+      const ROMol &query, const SearchResultCallback &callback,
+      const SubstructMatchParameters &matchParams = SubstructMatchParameters(),
+      const SynthonSpaceSearchParams &params = SynthonSpaceSearchParams());
+
   /*!
    * Perform a substructure search with the given generalized query
    * molecule across the synthonspace library.  Duplicate SMILES strings
@@ -222,6 +239,26 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSpace {
       const ROMol &query, const FingerprintGenerator<std::uint64_t> &fpGen,
       const SynthonSpaceSearchParams &params = SynthonSpaceSearchParams());
 
+  // Perform a fingerprint similarity search with the given query molecule
+  /*!
+   * Perform a fingerprint similarity search with the given query molecule
+   * across the synthonspace library.  Duplicate SMILES strings produced by
+   * different reactions will be returned.  Search results are returned
+   * incrementally through the provided callback, which will receive
+   * at most `toTryChunkSize` sized lists of ROMols at a time, thereby
+   * reducing the amount of memory required to hold search results.
+   *
+   * @param query : query molecule
+   * @param fpGen: a FingerprintGenerator object that will provide the
+   *               fingerprints for the similarity calculation
+   * @param callback: user-provided callback receiving chunks of ROMols.
+   * @param params : (optional) settings for the search
+   */
+  void fingerprintSearch(
+      const ROMol &query, const FingerprintGenerator<std::uint64_t> &fpGen,
+      const SearchResultCallback &callback,
+      const SynthonSpaceSearchParams &params = SynthonSpaceSearchParams());
+
   // Perform a RASCAL similarity search with the given query molecule
   // across the synthonspace library.  Duplicate SMILES strings produced by
   // different reactions will be returned.
@@ -241,6 +278,27 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSpace {
       const ROMol &query, const RascalMCES::RascalOptions &rascalOptions,
       const SynthonSpaceSearchParams &params = SynthonSpaceSearchParams());
 
+  // Perform a RASCAL similarity search with the given query molecule
+  /* across the synthonspace library.  Duplicate SMILES strings produced by
+   * different reactions will be returned.  Search results are returned
+   * incrementally through the provided callback, which will receive
+   * at most `toTryChunkSize` sized lists of ROMols at a time, thereby
+   * reducing the amount of memory required to hold search results.
+   *
+   * @param query : query molecule
+   * @param callback: user-provided callback receiving chunks of ROMols.
+   * @param rascalOptions: RASCAL options.  The similarityThreshold value
+   *                       in the rascalOptions will be used rather than
+   *                       params.similarityCutoff,
+   *                       but params.fragSimilarityAdjuster will be used
+   *                       to adjust the threshold for the fragment
+   *                       comparisons.
+   * @param params : (optional) settings for the search
+   */
+  void rascalSearch(
+      const ROMol &query, const RascalMCES::RascalOptions &rascalOptions,
+      const SearchResultCallback &callback,
+      const SynthonSpaceSearchParams &params = SynthonSpaceSearchParams());
   /*!
    *
    * @param inFilename: name of the file containing the synthon-based library.
@@ -261,7 +319,8 @@ class RDKIT_SYNTHONSPACESEARCH_EXPORT SynthonSpace {
    * SMILES,synton_id,synton_role,reaction_id
    * but with the 3rd column named differently but with the same meaning.
    * The formatting of the first 2 formats has been relaxed such that any
-   * whitespace may be used as the field separator.
+   * whitespace may be used as the field separator, but a tab is tried first
+   * so that a tab-separated file may have spaces in the columns.
    *
    * Attachment points are U, Np, Pu and Am for up to 4 synthons per reaction.
    * A product is created by taking a synthon from each synton# value and
